@@ -3,10 +3,11 @@ import time
 
 from timeit import default_timer
 
-from python_grpc_prometheus.server_metrics import SERVER_HANDLED_LATENCY_SECONDS
-from python_grpc_prometheus.server_metrics import SERVER_HANDLED_COUNTER
-from python_grpc_prometheus.server_metrics import SERVER_STARTED_COUNTER
-
+from python_grpc_prometheus.server_metrics import (SERVER_HANDLED_LATENCY_SECONDS,
+                                                   SERVER_HANDLED_COUNTER,
+                                                   SERVER_STARTED_COUNTER,
+                                                   SERVER_MSG_RECEIVED_TOTAL,
+                                                   SERVER_MSG_SENT_TOTAL)
 from python_grpc_prometheus.util import type_from_method
 from python_grpc_prometheus.util import code_to_string
 
@@ -67,40 +68,43 @@ class PromServerInterceptor(grpc.ServerInterceptor):
         def latency_wrapper(behavior, request_streaming, response_streaming):
             def new_behavior(request_or_iterator, service_context):
                 start = default_timer()
+
+                SERVER_MSG_RECEIVED_TOTAL.labels(
+                    grpc_type=grpc_type,
+                    grpc_service=grpc_service,
+                    grpc_method=grpc_method
+                ).inc()
+
+                # default
+                code = code_to_string(grpc.StatusCode.UNKNOWN)
+
                 try:
                     rsp = behavior(request_or_iterator, service_context)
                     if service_context._state.code is None:
-                        SERVER_HANDLED_COUNTER.labels(
-                            grpc_type=grpc_type,
-                            grpc_service=grpc_service,
-                            grpc_method=grpc_method,
-                            grpc_code=code_to_string(grpc.StatusCode.OK)
-                        ).inc()
+                        code = code_to_string(grpc.StatusCode.OK)
                     else:
-                        SERVER_HANDLED_COUNTER.labels(
-                            grpc_type=grpc_type,
-                            grpc_service=grpc_service,
-                            grpc_method=grpc_method,
-                            grpc_code=code_to_string(service_context._state.code)
-                        ).inc()
+                        code = code_to_string(service_context._state.code)
+
+                    SERVER_MSG_SENT_TOTAL.labels(
+                        grpc_type=grpc_type,
+                        grpc_service=grpc_service,
+                        grpc_method=grpc_method
+                    ).inc()
+
                     return rsp
                 except grpc.RpcError as e:
                     if isinstance(e, grpc.Call):
-                        SERVER_HANDLED_COUNTER.labels(
-                            grpc_type=grpc_type,
-                            grpc_service=grpc_service,
-                            grpc_method=grpc_method,
-                            grpc_code=code_to_string(e.code())
-                        ).inc()
-                    else:
-                        SERVER_HANDLED_COUNTER.labels(
-                            grpc_type=grpc_type,
-                            grpc_service=grpc_service,
-                            grpc_method=grpc_method,
-                            grpc_code=code_to_string(grpc.StatusCode.UNKNOWN)
-                        ).inc()
+                        code = code_to_string(e.code())
+
                     raise e
                 finally:
+                    SERVER_HANDLED_COUNTER.labels(
+                        grpc_type=grpc_type,
+                        grpc_service=grpc_service,
+                        grpc_method=grpc_method,
+                        grpc_code=code
+                    ).inc()
+
                     SERVER_HANDLED_LATENCY_SECONDS.labels(
                         grpc_type=grpc_type,
                         grpc_service=grpc_service,
